@@ -2,10 +2,7 @@
 import re
 from typing import Optional, Union, Dict
 import pandas as pd  # type: ignore
-try:
-    from .data.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
-except (ImportError, ModuleNotFoundError):
-    from data.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
+from receipt_parser.data.dicts import PRODUCTS, BRANDS, SLASH_PRODUCTS, BRANDS_WITH_NUMBERS  # type: ignore
 
 
 class Normalizer:
